@@ -6,9 +6,9 @@ class PhysicsConstantName(str, Enum):
     C = 'c'
     SPEED_OF_LIGHT = 'speed_of_light'
     G = 'G'
-    NEWTONIAN_GRAVIATION = 'newtonian_graviation'
+    NEWTONIAN_GRAVITATION = 'newtonian_gravitation'
     H = 'h'
-    PLANK_CONST = 'plank_const'
+    PLANCK_CONST = 'planck_const'
     MU_0 = 'mu_0'
     VACUUM_PERMEABILITY = 'vacuum_permeability'
     E_0 = 'E_0'
