@@ -5,7 +5,7 @@ class UnitForceFormat(str, Enum):
     NEWTON = 'newton'
     POUND = 'pound'
     DYNE = 'dyne'
-    KILOPOUND = 'kilopound'
+    KILOPOND = 'kilopond'
     POUNDAL = 'poundal'
 
     def __str__(self) -> str:
