@@ -3,12 +3,18 @@ from enum import Enum
 
 class UnitLengthFormat(str, Enum):
     METER = 'meter'
+    MILLIMETER = 'millimeter'
+    CENTIMETER = 'centimeter'
+    KILOMETER = 'kilometer'
     FOOT = 'foot'
     MIL = 'mil'
     INCH = 'inch'
     MILE = 'mile'
     NAUTICAL_MILE = 'nautical_mile'
     ASTRONOMICAL_UNIT = 'astronomical_unit'
+    LIGHTYEAR = 'lightyear'
+    PARSEC = 'parsec'
+    ANGSTROM = 'angstrom'
     CUBIT = 'cubit'
     FATHOM = 'fathom'
     CHAIN = 'chain'
@@ -17,9 +23,6 @@ class UnitLengthFormat(str, Enum):
     LEAGUE = 'league'
     NAUTICAL_LEAGUE = 'nautical_league'
     YARD = 'yard'
-    MILLIMETER = 'millimeter'
-    CENTIMETER = 'centimeter'
-    KILOMETER = 'kilometer'
 
     def __str__(self) -> str:
         return str(self.value)
